[Pkg-owncloud-commits] [owncloud] 41/205: Fix naming of param in private/server.php

David Prévot taffit at moszumanska.debian.org
Thu Jul 2 17:36:53 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch stable8
in repository owncloud.

commit 7e046d05956fdea9231b4d704abeb94bbd971934
Author: Morris Jobke <hey at morrisjobke.de>
Date:   Fri Jun 19 10:23:04 2015 +0200

    Fix naming of param in private/server.php
---
 lib/private/server.php | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/lib/private/server.php b/lib/private/server.php
index 497f432..7e233e6 100644
--- a/lib/private/server.php
+++ b/lib/private/server.php
@@ -785,19 +785,19 @@ class Server extends SimpleContainer implements IServerContainer {
 	/**
 	 * Get the certificate manager for the user
 	 *
 	 * @param string $uid (optional) if not specified the current loggedin user is used
 	 * @return \OCP\ICertificateManager | null if $uid is null and no user is logged in
 	 */
-	public function getCertificateManager($uid = null) {
-		if (is_null($uid)) {
+	public function getCertificateManager($userId = null) {
+		if (is_null($userId)) {
 			$userSession = $this->getUserSession();
 			$user = $userSession->getUser();
 			if (is_null($user)) {
 				return null;
 			}
-			$uid = $user->getUID();
+			$userId = $user->getUID();
 		}
-		return new CertificateManager($uid, new \OC\Files\View());
+		return new CertificateManager($userId, new \OC\Files\View());
 	}
 
 	/**
@@ -785,19 +785,19 @@ class Server extends SimpleContainer implements IServerContainer {
 	 * Get the certificate manager for the user
 	 *
-	 * @param string $uid (optional) if not specified the current loggedin user is used
+	 * @param string $userId (optional) if not specified the current loggedin user is used
 	 * @return \OCP\ICertificateManager | null if $uid is null and no user is logged in
 	 */

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git



More information about the Pkg-owncloud-commits mailing list